#[repr(transparent)]pub struct ApplName(pub MqStr<28>);Tuple Fields
0: MqStr<28>Trait Implementations
Sourceimpl ConnectOption<'_> for ApplName
impl ConnectOption<'_> for ApplName
Sourcefn apply_param(&self, structs: &mut ConnectStructs<'_>) -> ConnectStructFlags
fn apply_param(&self, structs: &mut ConnectStructs<'_>) -> ConnectStructFlags
Applies the type to to the structures contained in
ConnectStructs. Read moreSourcefn queue_manager_name(&self) -> Option<&QueueManagerName>
fn queue_manager_name(&self) -> Option<&QueueManagerName>
Returns the queue manager name to connect to, or
None to use the default queue manager name.impl Copy for ApplName
impl Eq for ApplName
impl StructuralPartialEq for ApplName